/* Table of languages.
   Copyright (C) 2001-2007 Free Software Foundation, Inc.
   Written by Bruno Haible <haible@clisp.cons.org>, 2005.

   This program is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */

#ifndef _LANG_TABLE_H
#define _LANG_TABLE_H

#include <stddef.h>

struct language_table_entry
{
  const char *code;
  const char *english;
};

extern struct language_table_entry language_table[];
extern const size_t language_table_size;

extern struct language_table_entry language_variant_table[];
extern const size_t language_variant_table_size;

#endif /* _LANG_TABLE_H */
